@@ -2,13 +2,13 @@ import json
 import os
 
 
-DIFFCHECKER_AUTH_TOKEN: str
-ETHERSCAN_API_KEY: str
+DIFFCHECKER_AUTH_TOKEN: str = ''
+ETHERSCAN_API_KEY: str = ''
 
 
 def load_api_keys():
     home = os.path.expanduser('~')
-    dirs = ['.', '..', home]
+    dirs = [home, '.', '..']
     keys = None
 
     for dir in dirs:
@@ -19,6 +19,7 @@ def load_api_keys():
         else:
             with key_file:
                 keys = json.loads(key_file.read())
+            break
 
         if keys is None:
             print('Cannot locate file "api_keys.json"')
@@ -27,4 +28,12 @@ def load_api_keys():
         global DIFFCHECKER_AUTH_TOKEN
         global ETHERSCAN_API_KEY
         DIFFCHECKER_AUTH_TOKEN = keys['diffchecker']
-        ETHERSCAN_API_KEY = keys['etherscan']
\ No newline at end of file
+        ETHERSCAN_API_KEY = keys['etherscan']
+
+    
+def get_diffchecker_auth_token() -> str:
+    return DIFFCHECKER_AUTH_TOKEN
+
+
+def get_etherscan_api_key() -> str:
+    return ETHERSCAN_API_KEY
\ No newline at end of file
